.. include:: ../references.txt

.. _api_modeling:

*****************************
modeling - Models and fitting
*****************************

.. currentmodule:: gammapy.modeling

.. automodapi:: gammapy.modeling
    :no-inheritance-diagram:
    :include-all-objects:

.. automodapi:: gammapy.modeling.models
    :no-inheritance-diagram:
    :include-all-objects:
